==> plantuml-libs-9.0.0.tgz: package/distribution/aws-q2-2022/Resource/LoT/AwsIoTDeviceDefenderIoTDeviceJobs.md <==
# AwsIoTDeviceDefenderIoTDeviceJobs


```text
aws-q2-2022/Resource/LoT/AwsIoTDeviceDefenderIoTDeviceJobs
```

```text
include('aws-q2-2022/Resource/LoT/AwsIoTDeviceDefenderIoTDeviceJobs')
```



| Illustration | AwsIoTDeviceDefenderIoTDeviceJobs | AwsIoTDeviceDefenderIoTDeviceJobsCard | AwsIoTDeviceDefenderIoTDeviceJobsGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q2-2022/Resource/LoT/AwsIoTDeviceDefenderIoTDeviceJobs.png) | ![illustration for AwsIoTDeviceDefenderIoTDeviceJobs](../../../aws-q2-2022/Resource/LoT/AwsIoTDeviceDefenderIoTDeviceJobs.Local.png) | ![illustration for AwsIoTDeviceDefenderIoTDeviceJobsCard](../../../aws-q2-2022/Resource/LoT/AwsIoTDeviceDefenderIoTDeviceJobsCard.Local.png) | ![illustration for AwsIoTDeviceDefenderIoTDeviceJobsGroup](../../../aws-q2-2022/Resource/LoT/AwsIoTDeviceDefenderIoTDeviceJobsGroup.Local.png) |




## AwsIoTDeviceDefenderIoTDeviceJobs

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTDeviceDefenderIoTDeviceJobs
include('aws-q2-2022/Resource/LoT/AwsIoTDeviceDefenderIoTDeviceJobs')

' renders the element
AwsIoTDeviceDefenderIoTDeviceJobs('AwsIoTDeviceDefenderIoTDeviceJobs', 'Aws Io T Device Defender Io T Device Jobs', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTDeviceDefenderIoTDeviceJobs
include('aws-q2-2022/Resource/LoT/AwsIoTDeviceDefenderIoTDeviceJobs')

' renders the element
AwsIoTDeviceDefenderIoTDeviceJobs('AwsIoTDeviceDefenderIoTDeviceJobs', 'Aws Io T Device Defender Io T Device Jobs', 'an optional tech label')
@enduml
```

## AwsIoTDeviceDefenderIoTDeviceJobsCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTDeviceDefenderIoTDeviceJobsCard
include('aws-q2-2022/Resource/LoT/AwsIoTDeviceDefenderIoTDeviceJobs')

' renders the element
AwsIoTDeviceDefenderIoTDeviceJobsCard('AwsIoTDeviceDefenderIoTDeviceJobsCard', 'Aws Io T Device Defender Io T Device Jobs Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTDeviceDefenderIoTDeviceJobsCard
include('aws-q2-2022/Resource/LoT/AwsIoTDeviceDefenderIoTDeviceJobs')

' renders the element
AwsIoTDeviceDefenderIoTDeviceJobsCard('AwsIoTDeviceDefenderIoTDeviceJobsCard', 'Aws Io T Device Defender Io T Device Jobs Card', 'an optional description')
@enduml
```

## AwsIoTDeviceDefenderIoTDeviceJobsGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTDeviceDefenderIoTDeviceJobsGroup
include('aws-q2-2022/Resource/LoT/AwsIoTDeviceDefenderIoTDeviceJobs')

' renders the element
AwsIoTDeviceDefenderIoTDeviceJobsGroup('AwsIoTDeviceDefenderIoTDeviceJobsGroup', 'Aws Io T Device Defender Io T Device Jobs Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsIoTDeviceDefenderIoTDeviceJobsGroup
include('aws-q2-2022/Resource/LoT/AwsIoTDeviceDefenderIoTDeviceJobs')

' renders the element
AwsIoTDeviceDefenderIoTDeviceJobsGroup('AwsIoTDeviceDefenderIoTDeviceJobsGroup', 'Aws Io T Device Defender Io T Device Jobs Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/aws-q1-2022/Resource/LoT/AwsIoTDeviceDefenderIoTDeviceJobs.md <==
# AwsIoTDeviceDefenderIoTDeviceJobs


```text
aws-q1-2022/Resource/LoT/AwsIoTDeviceDefenderIoTDeviceJobs
```

```text
include('aws-q1-2022/Resource/LoT/AwsIoTDeviceDefenderIoTDeviceJobs')
```



| Illustration | AwsIoTDeviceDefenderIoTDeviceJobs | AwsIoTDeviceDefenderIoTDeviceJobsCard | AwsIoTDeviceDefenderIoTDeviceJobsGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q1-2022/Resource/LoT/AwsIoTDeviceDefenderIoTDeviceJobs.png) | ![illustration for AwsIoTDeviceDefenderIoTDeviceJobs](../../../aws-q1-2022/Resource/LoT/AwsIoTDeviceDefenderIoTDeviceJobs.Local.png) | ![illustration for AwsIoTDeviceDefenderIoTDeviceJobsCard](../../../aws-q1-2022/Resource/LoT/AwsIoTDeviceDefenderIoTDeviceJobsCard.Local.png) | ![illustration for AwsIoTDeviceDefenderIoTDeviceJobsGroup](../../../aws-q1-2022/Resource/LoT/AwsIoTDeviceDefenderIoTDeviceJobsGroup.Local.png) |




## AwsIoTDeviceDefenderIoTDeviceJobs

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTDeviceDefenderIoTDeviceJobs
include('aws-q1-2022/Resource/LoT/AwsIoTDeviceDefenderIoTDeviceJobs')

' renders the element
AwsIoTDeviceDefenderIoTDeviceJobs('AwsIoTDeviceDefenderIoTDeviceJobs', 'Aws Io T Device Defender Io T Device Jobs', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTDeviceDefenderIoTDeviceJobs
include('aws-q1-2022/Resource/LoT/AwsIoTDeviceDefenderIoTDeviceJobs')

' renders the element
AwsIoTDeviceDefenderIoTDeviceJobs('AwsIoTDeviceDefenderIoTDeviceJobs', 'Aws Io T Device Defender Io T Device Jobs', 'an optional tech label', 'an optional description')
@enduml
```

## AwsIoTDeviceDefenderIoTDeviceJobsCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTDeviceDefenderIoTDeviceJobsCard
include('aws-q1-2022/Resource/LoT/AwsIoTDeviceDefenderIoTDeviceJobs')

' renders the element
AwsIoTDeviceDefenderIoTDeviceJobsCard('AwsIoTDeviceDefenderIoTDeviceJobsCard', 'Aws Io T Device Defender Io T Device Jobs Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTDeviceDefenderIoTDeviceJobsCard
include('aws-q1-2022/Resource/LoT/AwsIoTDeviceDefenderIoTDeviceJobs')

' renders the element
AwsIoTDeviceDefenderIoTDeviceJobsCard('AwsIoTDeviceDefenderIoTDeviceJobsCard', 'Aws Io T Device Defender Io T Device Jobs Card', 'an optional description')
@enduml
```

## AwsIoTDeviceDefenderIoTDeviceJobsGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTDeviceDefenderIoTDeviceJobsGroup
include('aws-q1-2022/Resource/LoT/AwsIoTDeviceDefenderIoTDeviceJobs')

' renders the element
AwsIoTDeviceDefenderIoTDeviceJobsGroup('AwsIoTDeviceDefenderIoTDeviceJobsGroup', 'Aws Io T Device Defender Io T Device Jobs Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTDeviceDefenderIoTDeviceJobsGroup
include('aws-q1-2022/Resource/LoT/AwsIoTDeviceDefenderIoTDeviceJobs')

' renders the element
AwsIoTDeviceDefenderIoTDeviceJobsGroup('AwsIoTDeviceDefenderIoTDeviceJobsGroup', 'Aws Io T Device Defender Io T Device Jobs Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
